@@ -13,8 +13,8 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-#echo(dptFileVersion)#
-#echo(__FILEPATH__)#
+v1.0.3
+dpt_file/__init__.py
 """
 
 from .file import File
