@@ -13,8 +13,8 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-#echo(dptFileVersion)#
-#echo(__FILEPATH__)#
+v1.0.3
+dpt_file/file.py
 """
 
 # pylint: disable=import-error,invalid-name,no-member,undefined-variable
@@ -58,7 +58,7 @@ Get file objects to work with files easily.
     """
 
     # pylint: disable=bad-option-value,slots-on-old-class
-    __slots__ = [ "binary",
+    __slots__ = ( "binary",
                   "chmod",
                   "file_path_name",
                   "file_size",
@@ -68,7 +68,7 @@ Get file objects to work with files easily.
                   "readonly",
                   "timeout_retries",
                   "umask"
-                ]
+                )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
@@ -279,7 +279,7 @@ python.org: Flush and close this stream.
 
         # global: _USE_FILE_LOCKING
 
-        if (self._log_handler is not None): self._log_handler.debug("#echo(__FILEPATH__)# -file.close()- (#echo(__LINE__)#)")
+        if (self._log_handler is not None): self._log_handler.debug("dpt_file/file.py -file.close()- (282)")
         _return = False
 
         if (self._handle is not None):
@@ -352,14 +352,14 @@ Changes file locking if needed.
 :since:  v1.0.0
         """
 
-        if (self._log_handler is not None): self._log_handler.debug("#echo(__FILEPATH__)# -file.lock({0})- (#echo(__LINE__)#)", lock_mode)
+        if (self._log_handler is not None): self._log_handler.debug("dpt_file/file.py -file.lock({0})- (355)", lock_mode)
 
         _return = False
 
         if (self._handle is None):
-            if (self._log_handler is not None): self._log_handler.warning("#echo(__FILEPATH__)# -file.lock()- reporting: File handle invalid")
+            if (self._log_handler is not None): self._log_handler.warning("dpt_file/file.py -file.lock()- reporting: File handle invalid")
         elif (lock_mode == "w" and self.readonly):
-            if (self._log_handler is not None): self._log_handler.error("#echo(__FILEPATH__)# -file.lock()- reporting: File handle is in readonly mode")
+            if (self._log_handler is not None): self._log_handler.error("dpt_file/file.py -file.lock()- reporting: File handle is in readonly mode")
         elif (lock_mode == self._handle_lock): _return = True
         else:
             timeout_retries = self.timeout_retries
@@ -377,7 +377,7 @@ Changes file locking if needed.
                 #
             #
 
-            if (timeout_retries > -1 and self._log_handler is not None): self._log_handler.error("#echo(__FILEPATH__)# -file.lock()- reporting: File lock change failed")
+            if (timeout_retries > -1 and self._log_handler is not None): self._log_handler.error("dpt_file/file.py -file.lock()- reporting: File lock change failed")
         #
 
         return _return
@@ -462,7 +462,7 @@ Opens a file session.
 
         if (str is not _PY_UNICODE_TYPE and type(file_path_name) is _PY_UNICODE_TYPE): file_path_name = _PY_STR(file_path_name, "utf-8")
 
-        if (self._log_handler is not None): self._log_handler.debug("#echo(__FILEPATH__)# -file.open({0}, {1})- (#echo(__LINE__)#)", file_path_name, file_mode)
+        if (self._log_handler is not None): self._log_handler.debug("dpt_file/file.py -file.open({0}, {1})- (465)", file_path_name, file_mode)
 
         if (self._handle is None):
             exists = False
@@ -481,7 +481,7 @@ Opens a file session.
             if (_return):
                 try: self._handle = self._open(file_path_name, file_mode, is_binary)
                 except IOError: _return = False
-            elif (self._log_handler is not None): self._log_handler.warning("#echo(__FILEPATH__)# -file.open()- reporting: Failed opening {0} - file does not exist", file_path_name)
+            elif (self._log_handler is not None): self._log_handler.warning("dpt_file/file.py -file.open()- reporting: Failed opening {0} - file does not exist", file_path_name)
 
             if (self._handle is None):
                 if ((not exists) and (not self.readonly)):
@@ -543,7 +543,7 @@ python.org: Read up to n bytes from the object and return them.
 
         # global: _PY_BYTES_TYPE
 
-        if (self._log_handler is not None): self._log_handler.debug("#echo(__FILEPATH__)# -file.read({0:d}, {1:d})- (#echo(__LINE__)#)", n, timeout)
+        if (self._log_handler is not None): self._log_handler.debug("dpt_file/file.py -file.read({0:d}, {1:d})- (546)", n, timeout)
 
         _return = None
 
@@ -563,7 +563,7 @@ python.org: Read up to n bytes from the object and return them.
 
             if ((bytes_unread > 0 or (n == 0 and self.is_eof))
                 and self._log_handler is not None
-               ): self._log_handler.error("#echo(__FILEPATH__)# -file.read()- reporting: Timeout occured before EOF")
+               ): self._log_handler.error("dpt_file/file.py -file.read()- reporting: Timeout occured before EOF")
         #
 
         return _return
@@ -579,7 +579,7 @@ python.org: Change the stream position to the given byte offset.
 :since:  v1.0.0
         """
 
-        if (self._log_handler is not None): self._log_handler.debug("#echo(__FILEPATH__)# -file.seek({0:d})- (#echo(__LINE__)#)", offset)
+        if (self._log_handler is not None): self._log_handler.debug("dpt_file/file.py -file.seek({0:d})- (582)", offset)
         return (-1 if (self._handle is None) else self._handle.seek(offset))
     #
 
@@ -605,7 +605,7 @@ python.org: Resize the stream to the given size in bytes.
         """
 
         if (new_size is None): new_size = max(0, self.tell())
-        if (self._log_handler is not None): self._log_handler.debug("#echo(__FILEPATH__)# -file.truncate({0:d})- (#echo(__LINE__)#)", new_size)
+        if (self._log_handler is not None): self._log_handler.debug("dpt_file/file.py -file.truncate({0:d})- (608)", new_size)
 
         if (self.lock("w")):
             _return = self._handle.truncate(new_size)
@@ -629,7 +629,7 @@ raw stream and return the number of bytes written.
 
         # global: _PY_BYTES, _PY_BYTES_TYPE
 
-        if (self._log_handler is not None): self._log_handler.debug("#echo(__FILEPATH__)# -file.write({0:d})- (#echo(__LINE__)#)", timeout)
+        if (self._log_handler is not None): self._log_handler.debug("dpt_file/file.py -file.write({0:d})- (632)", timeout)
 
         _return = 0
 
@@ -654,7 +654,7 @@ raw stream and return the number of bytes written.
 
             if (bytes_unwritten > 0):
                 self.file_size = os.stat(path.normpath(self.file_path_name)).st_size
-                if (self._log_handler is not None): self._log_handler.error("#echo(__FILEPATH__)# -file.write()- reporting: Timeout occured before EOF")
+                if (self._log_handler is not None): self._log_handler.error("dpt_file/file.py -file.write()- reporting: Timeout occured before EOF")
             elif (new_size > 0): self.file_size = new_size
         #
 
